==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/DateTimeInput.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { MaskInputBase } from "./MaskInputBase";
import { enumGetBox, markType } from "igniteui-react-core";
import { DatePartDeltas } from "./DatePartDeltas";
import { ComponentDateValueChangedEventArgs } from "./ComponentDateValueChangedEventArgs";
import { DatePart_$type } from "./DatePart";
/**
 * @hidden
 */
var DateTimeInput = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DateTimeInput, _super);
    function DateTimeInput() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.change = null;
        return _this;
    }
    Object.defineProperty(DateTimeInput.prototype, "al", {
        get: function () {
            var ret_ = this.f.m("inputFormat");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("inputFormat", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DateTimeInput.prototype, "aj", {
        get: function () {
            var ret_ = this.f.m("value");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("value", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DateTimeInput.prototype, "ai", {
        get: function () {
            var ret_ = this.f.m("minValue");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("minValue", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DateTimeInput.prototype, "ah", {
        get: function () {
            var ret_ = this.f.m("maxValue");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("maxValue", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DateTimeInput.prototype, "ak", {
        get: function () {
            var ret_ = this.f.m("displayFormat");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("displayFormat", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DateTimeInput.prototype, "af", {
        get: function () {
            var ret_ = this.f.l("spinDelta", function (a) { return new DatePartDeltas(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("spinDelta", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DateTimeInput.prototype, "ag", {
        get: function () {
            var ret_ = this.f.m("spinLoop");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("spinLoop", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DateTimeInput.prototype, "am", {
        get: function () {
            var ret_ = this.f.m("locale");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("locale", value_);
        },
        enumerable: false,
        configurable: true
    });
    DateTimeInput.prototype.changeChanged = function () {
        var _this = this;
        if (this.change != null) {
            this.f.q("change", function (a) { return _this.change(_this, ComponentDateValueChangedEventArgs.a(a)); });
        }
        else {
            this.f.t("change");
        }
    };
    DateTimeInput.prototype.aq = function () {
        this.nativeElement.connectedCallback();
    };
    DateTimeInput.prototype.ar = function () {
        this.nativeElement.reportValidity();
    };
    DateTimeInput.prototype.ao = function () {
        this.nativeElement.checkValidity();
    };
    DateTimeInput.prototype.at = function (a, b) {
        this.nativeElement.stepUp(this.f.h(enumGetBox(DatePart_$type, a)), this.f.h(b));
    };
    DateTimeInput.prototype.as = function (a, b) {
        this.nativeElement.stepDown(this.f.h(enumGetBox(DatePart_$type, a)), this.f.h(b));
    };
    DateTimeInput.prototype.ap = function () {
        this.nativeElement.clear();
    };
    DateTimeInput.$t = markType(DateTimeInput, 'DateTimeInput', MaskInputBase.$);
    return DateTimeInput;
}(MaskInputBase));
export { DateTimeInput };

==> igniteui-react-18.5.2-beta.0.tgz: package/esm5/lib/DateTimeInput.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { MaskInputBase } from "./MaskInputBase";
import { enumGetBox, markType } from "igniteui-react-core";
import { DatePartDeltas } from "./DatePartDeltas";
import { ComponentDateValueChangedEventArgs } from "./ComponentDateValueChangedEventArgs";
import { DatePart_$type } from "./DatePart";
/**
 * @hidden
 */
var DateTimeInput = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DateTimeInput, _super);
    function DateTimeInput() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.change = null;
        return _this;
    }
    Object.defineProperty(DateTimeInput.prototype, "ao", {
        get: function () {
            var ret_ = this.f.n("inputFormat");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("inputFormat", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DateTimeInput.prototype, "am", {
        get: function () {
            var ret_ = this.f.n("value");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("value", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DateTimeInput.prototype, "ak", {
        get: function () {
            var ret_ = this.f.n("min");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("min", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DateTimeInput.prototype, "ai", {
        get: function () {
            var ret_ = this.f.n("max");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("max", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DateTimeInput.prototype, "al", {
        get: function () {
            var ret_ = this.f.n("minValue");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("minValue", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DateTimeInput.prototype, "aj", {
        get: function () {
            var ret_ = this.f.n("maxValue");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("maxValue", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DateTimeInput.prototype, "an", {
        get: function () {
            var ret_ = this.f.n("displayFormat");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("displayFormat", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DateTimeInput.prototype, "ag", {
        get: function () {
            var ret_ = this.f.m("spinDelta", function (a) { return new DatePartDeltas(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("spinDelta", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DateTimeInput.prototype, "ah", {
        get: function () {
            var ret_ = this.f.n("spinLoop");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("spinLoop", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DateTimeInput.prototype, "ap", {
        get: function () {
            var ret_ = this.f.n("locale");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("locale", value_);
        },
        enumerable: false,
        configurable: true
    });
    DateTimeInput.prototype.changeChanged = function () {
        var _this = this;
        if (this.change != null) {
            this.f.r("change", function (a) { return _this.change(_this, ComponentDateValueChangedEventArgs.a(a)); });
        }
        else {
            this.f.u("change");
        }
    };
    DateTimeInput.prototype.as = function () {
        this.nativeElement.connectedCallback();
    };
    DateTimeInput.prototype.au = function (a, b) {
        if (b === void 0) {
            b = -1;
        }
        this.nativeElement.stepUp(this.f.i(enumGetBox(DatePart_$type, a)), this.f.i(b));
    };
    DateTimeInput.prototype.at = function (a, b) {
        if (b === void 0) {
            b = -1;
        }
        this.nativeElement.stepDown(this.f.i(enumGetBox(DatePart_$type, a)), this.f.i(b));
    };
    DateTimeInput.prototype.ar = function () {
        this.nativeElement.clear();
    };
    DateTimeInput.$t = markType(DateTimeInput, 'DateTimeInput', MaskInputBase.$);
    return DateTimeInput;
}(MaskInputBase));
export { DateTimeInput };
